import { RouterType } from 'aws-cdk-lib/aws-ec2';
import * as cdk from 'aws-cdk-lib/core';
import { Construct } from 'constructs';
import { ITransitGatewayRouteTable } from './transit-gateway-route-table';
import { AttachVpcOptions, ITransitGatewayVpcAttachment } from './transit-gateway-vpc-attachment';
import { IRouteTarget } from './route';
/**
 * Represents a Transit Gateway.
 */
export interface ITransitGateway extends cdk.IResource, IRouteTarget {
    /**
     * The unique identifier of the Transit Gateway.
     *
     * This ID is automatically assigned by AWS upon creation of the Transit Gateway
     * and is used to reference it in various configurations and operations.
     * @attribute
     */
    readonly transitGatewayId: string;
    /**
     * The Amazon Resource Name (ARN) of the Transit Gateway.
     *
     * The ARN uniquely identifies the Transit Gateway across AWS and is commonly
     * used for permissions and resource tracking.
     * @attribute
     */
    readonly transitGatewayArn: string;
    /**
     * The default route table associated with the Transit Gateway.
     *
     * This route table is created by the CDK and is used to manage the routes
     * for attachments that do not have an explicitly defined route table association.
     */
    readonly defaultRouteTable: ITransitGatewayRouteTable;
    /**
     * Indicates whether new attachments are automatically associated with the default route table.
     *
     * If set to `true`, any VPC or VPN attachment will be automatically associated with
     * the default route table unless otherwise specified.
     */
    readonly defaultRouteTableAssociation: boolean;
    /**
     * Indicates whether route propagation to the default route table is enabled.
     *
     * When set to `true`, routes from attachments will be automatically propagated
     * to the default route table unless propagation is explicitly disabled.
     */
    readonly defaultRouteTablePropagation: boolean;
    /**
     * Whether or not DNS support is enabled on the Transit Gateway.
     */
    readonly dnsSupport: boolean;
    /**
     * Whether or not security group referencing support is enabled on the Transit Gateway.
     */
    readonly securityGroupReferencingSupport: boolean;
}
/**
 * Common properties for creating a Transit Gateway resource.
 */
export interface TransitGatewayProps {
    /**
     * Physical name of this Transit Gateway.
     *
     * @default - Assigned by CloudFormation.
     */
    readonly transitGatewayName?: string;
    /**
     * A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs.
     *
     * @default - undefined, 64512 is assigned by CloudFormation.
     */
    readonly amazonSideAsn?: number;
    /**
     * Enable or disable automatic acceptance of cross-account attachment requests.
     *
     * @default - disable (false)
     */
    readonly autoAcceptSharedAttachments?: boolean;
    /**
     * Enable or disable automatic association with the default association route table.
     *
     * @default - enable (true)
     */
    readonly defaultRouteTableAssociation?: boolean;
    /**
     * Enable or disable automatic propagation of routes to the default propagation route table.
     *
     * @default - enable (true)
     */
    readonly defaultRouteTablePropagation?: boolean;
    /**
     * The description of the transit gateway.
     *
     * @default - no description
     */
    readonly description?: string;
    /**
     * Enable or disable DNS support.
     *
     * If dnsSupport is enabled on a VPC Attachment, this also needs to be enabled for the feature to work.
     * Otherwise the resources will still deploy but the feature will not work.
     *
     * @default - enable (true)
     */
    readonly dnsSupport?: boolean;
    /**
     * Enable or disable security group referencing support
     *
     * If securityGroupReferencingSupport is enabled on a VPC Attachment, this also needs to be enabled for the feature to work.
     * Otherwise the resources will still deploy but the feature will not work.
     *
     * @default - disable (false)
     */
    readonly securityGroupReferencingSupport?: boolean;
    /**
     * The transit gateway CIDR blocks.
     *
     * @default - none
     */
    readonly transitGatewayCidrBlocks?: string[];
}
/**
 * A Transit Gateway.
 * @internal
 */
declare abstract class TransitGatewayBase extends cdk.Resource implements ITransitGateway, IRouteTarget {
    abstract readonly routerType: RouterType;
    abstract readonly routerTargetId: string;
    abstract readonly transitGatewayId: string;
    abstract readonly transitGatewayArn: string;
    abstract readonly defaultRouteTable: ITransitGatewayRouteTable;
    abstract readonly defaultRouteTableAssociation: boolean;
    abstract readonly defaultRouteTablePropagation: boolean;
    abstract readonly dnsSupport: boolean;
    abstract readonly securityGroupReferencingSupport: boolean;
    /**
     * Adds a new route table to the Transit Gateway.
     *
     * @returns The created Transit Gateway route table.
     */
    addRouteTable(id: string): ITransitGatewayRouteTable;
    /**
     * Attaches a VPC to the Transit Gateway.
     *
     * @returns The created Transit Gateway VPC attachment.
     */
    attachVpc(id: string, options: AttachVpcOptions): ITransitGatewayVpcAttachment;
}
/**
 * Creates a Transit Gateway.
 *
 * @resource AWS::EC2::TransitGateway
 */
export declare class TransitGateway extends TransitGatewayBase {
    /** Uniquely identifies this class. */
    static readonly PROPERTY_INJECTION_ID: string;
    readonly routerType: RouterType;
    readonly routerTargetId: string;
    readonly transitGatewayId: string;
    readonly transitGatewayArn: string;
    readonly defaultRouteTable: ITransitGatewayRouteTable;
    readonly defaultRouteTableAssociation: boolean;
    readonly defaultRouteTablePropagation: boolean;
    readonly dnsSupport: boolean;
    readonly securityGroupReferencingSupport: boolean;
    constructor(scope: Construct, id: string, props?: TransitGatewayProps);
}
export {};
